@@ -8,24 +8,24 @@
 This file INTENTIONALLY has NO module dependencies!
 """
 from __future__ import absolute_import, division, print_function, unicode_literals
-from .compatibility import *  # NOQA
 
-import csv
-import imp  # keeping this deprecated module as soon as we keep supporting Py2.7
-import io
+import imp
 import itertools
 import os
 import re
-import shutil
+import sys
+import zipfile
+import io
 import string
 import subprocess
-import sys
+import csv
+import shutil
 import tempfile
-import zipfile
 
-from h2o.backend.server import H2OLocalServer
 from h2o.exceptions import H2OValueError
+from h2o.utils.compatibility import *  # NOQA
 from h2o.utils.typechecks import assert_is_type, is_type, numeric
+from h2o.backend.server import H2OLocalServer
 
 _id_ctr = 0
 
@@ -371,7 +371,7 @@ h2o_predictor_class = "hex.genmodel.tools.PredictCsv"
 
 
 def mojo_predict_pandas(dataframe, mojo_zip_path, genmodel_jar_path=None, classpath=None, java_options=None, 
-                        verbose=False, setInvNumNA=False, predict_contributions=False):
+                        verbose=False, setInvNumNA=False):
     """
     MOJO scoring function to take a Pandas frame and use MOJO model as zip file to score.
 
@@ -383,8 +383,6 @@ def mojo_predict_pandas(dataframe, mojo_zip_path, genmodel_jar_path=None, classp
         (default) then the default classpath for this MOJO model will be used.
     :param java_options: Optional, custom user defined options for Java. By default ``-Xmx4g`` is used.
     :param verbose: Optional, if True, then additional debug information will be printed. False by default.
-    :param predict_contributions: if True, then return prediction contributions instead of regular predictions 
-        (only for tree-based models).
     :return: Pandas frame with predictions
     """
     tmp_dir = tempfile.mkdtemp()
@@ -398,15 +396,14 @@ def mojo_predict_pandas(dataframe, mojo_zip_path, genmodel_jar_path=None, classp
         dataframe.to_csv(input_csv_path)
         mojo_predict_csv(input_csv_path=input_csv_path, mojo_zip_path=mojo_zip_path,
                          output_csv_path=prediction_csv_path, genmodel_jar_path=genmodel_jar_path,
-                         classpath=classpath, java_options=java_options, verbose=verbose, setInvNumNA=setInvNumNA,
-                         predict_contributions=predict_contributions)
+                         classpath=classpath, java_options=java_options, verbose=verbose, setInvNumNA=setInvNumNA)
         return pandas.read_csv(prediction_csv_path)
     finally:
         shutil.rmtree(tmp_dir)
 
 
 def mojo_predict_csv(input_csv_path, mojo_zip_path, output_csv_path=None, genmodel_jar_path=None, classpath=None, 
-                     java_options=None, verbose=False, setInvNumNA=False, predict_contributions=False):
+                     java_options=None, verbose=False, setInvNumNA=False):
     """
     MOJO scoring function to take a CSV file and use MOJO model as zip file to score.
 
@@ -420,8 +417,6 @@ def mojo_predict_csv(input_csv_path, mojo_zip_path, output_csv_path=None, genmod
         (default) then the default classpath for this MOJO model will be used.
     :param java_options: Optional, custom user defined options for Java. By default ``-Xmx4g -XX:ReservedCodeCacheSize=256m`` is used.
     :param verbose: Optional, if True, then additional debug information will be printed. False by default.
-    :param predict_contributions: if True, then return prediction contributions instead of regular predictions 
-        (only for tree-based models).
     :return: List of computed predictions
     """
     default_java_options = '-Xmx4g -XX:ReservedCodeCacheSize=256m'
@@ -482,10 +477,7 @@ def mojo_predict_csv(input_csv_path, mojo_zip_path, output_csv_path=None, genmod
 
     if setInvNumNA:
         cmd.append('--setConvertInvalidNum')
-
-    if predict_contributions:
-        cmd.append('--predictContributions')
-
+        
     if verbose:
         cmd_str = " ".join(cmd)
         print("java cmd:\t%s" % cmd_str)
